BalderHub-Textual
=================

The BalderHub Textual package provides helper objects to test `Textual Applications <https://textual.textualize.io/>`_
with Balder.

.. note::
   Please note, this package is still under development. If you would like to contribute, take a look into the
   `GitHub project <https://github.com/balder-dev/balderhub-textual>`_.

This is a BalderHub package for the `Balder <https://docs.balder.dev/>`_ test framework. It will be used for writing
Balder tests with the `Textual Applications <https://textual.textualize.io/>`_. If you are new to Balder check out the
`official documentation <https://docs.balder.dev>`_ first.


.. toctree::
   :maxdepth: 2

   installation.rst
   topic_intro.rst
   scenarios.rst
   features.rst
   examples.rst
   utilities.rst
